# boaw

## Description:
This library is used to keep us online at work.
Note: This is just for educational purpose. We are not responsible if you get in conflicts because of this library. Please use this library
only if you agree with the above Note

## Usage:

1. To Stay in online:

    Import the boaw library:

        import boaw

    Using the boaw library:

        boaw.stay_online()

    Now just hover your mouse on start button and it keeps clicking it every 5 seconds, thereby helping you to stay online.